# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/targeting_dimension.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/targeting_dimension.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\027TargetingDimensionProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\n=google/ads/googleads_v1/proto/enums/targeting_dimension.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xc4\x01\n\x16TargetingDimensionEnum\"\xa9\x01\n\x12TargetingDimension\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07KEYWORD\x10\x02\x12\x0c\n\x08\x41UDIENCE\x10\x03\x12\t\n\x05TOPIC\x10\x04\x12\n\n\x06GENDER\x10\x05\x12\r\n\tAGE_RANGE\x10\x06\x12\r\n\tPLACEMENT\x10\x07\x12\x13\n\x0fPARENTAL_STATUS\x10\x08\x12\x10\n\x0cINCOME_RANGE\x10\tB\xec\x01\n!com.google.ads.googleads.v1.enumsB\x17TargetingDimensionProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_TARGETINGDIMENSIONENUM_TARGETINGDIMENSION = _descriptor.EnumDescriptor(
  name='TargetingDimension',
  full_name='google.ads.googleads.v1.enums.TargetingDimensionEnum.TargetingDimension',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUDIENCE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOPIC', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENDER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARENTAL_STATUS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=154,
  serialized_end=323,
)
_sym_db.RegisterEnumDescriptor(_TARGETINGDIMENSIONENUM_TARGETINGDIMENSION)


_TARGETINGDIMENSIONENUM = _descriptor.Descriptor(
  name='TargetingDimensionEnum',
  full_name='google.ads.googleads.v1.enums.TargetingDimensionEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TARGETINGDIMENSIONENUM_TARGETINGDIMENSION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=323,
)

_TARGETINGDIMENSIONENUM_TARGETINGDIMENSION.containing_type = _TARGETINGDIMENSIONENUM
DESCRIPTOR.message_types_by_name['TargetingDimensionEnum'] = _TARGETINGDIMENSIONENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TargetingDimensionEnum = _reflection.GeneratedProtocolMessageType('TargetingDimensionEnum', (_message.Message,), dict(
  DESCRIPTOR = _TARGETINGDIMENSIONENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.targeting_dimension_pb2'
  ,
  __doc__ = """The dimensions that can be targeted.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.TargetingDimensionEnum)
  ))
_sym_db.RegisterMessage(TargetingDimensionEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/url_field_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/url_field_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\022UrlFieldErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n:google/ads/googleads_v2/proto/errors/url_field_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xb6\x0e\n\x11UrlFieldErrorEnum\"\xa0\x0e\n\rUrlFieldError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12!\n\x1dINVALID_TRACKING_URL_TEMPLATE\x10\x02\x12(\n$INVALID_TAG_IN_TRACKING_URL_TEMPLATE\x10\x03\x12%\n!MISSING_TRACKING_URL_TEMPLATE_TAG\x10\x04\x12-\n)MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE\x10\x05\x12-\n)INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE\x10\x06\x12#\n\x1fMALFORMED_TRACKING_URL_TEMPLATE\x10\x07\x12)\n%MISSING_HOST_IN_TRACKING_URL_TEMPLATE\x10\x08\x12(\n$INVALID_TLD_IN_TRACKING_URL_TEMPLATE\x10\t\x12.\n*REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG\x10\n\x12\x15\n\x11INVALID_FINAL_URL\x10\x0b\x12\x1c\n\x18INVALID_TAG_IN_FINAL_URL\x10\x0c\x12\"\n\x1eREDUNDANT_NESTED_FINAL_URL_TAG\x10\r\x12!\n\x1dMISSING_PROTOCOL_IN_FINAL_URL\x10\x0e\x12!\n\x1dINVALID_PROTOCOL_IN_FINAL_URL\x10\x0f\x12\x17\n\x13MALFORMED_FINAL_URL\x10\x10\x12\x1d\n\x19MISSING_HOST_IN_FINAL_URL\x10\x11\x12\x1c\n\x18INVALID_TLD_IN_FINAL_URL\x10\x12\x12\x1c\n\x18INVALID_FINAL_MOBILE_URL\x10\x13\x12#\n\x1fINVALID_TAG_IN_FINAL_MOBILE_URL\x10\x14\x12)\n%REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG\x10\x15\x12(\n$MISSING_PROTOCOL_IN_FINAL_MOBILE_URL\x10\x16\x12(\n$INVALID_PROTOCOL_IN_FINAL_MOBILE_URL\x10\x17\x12\x1e\n\x1aMALFORMED_FINAL_MOBILE_URL\x10\x18\x12$\n MISSING_HOST_IN_FINAL_MOBILE_URL\x10\x19\x12#\n\x1fINVALID_TLD_IN_FINAL_MOBILE_URL\x10\x1a\x12\x19\n\x15INVALID_FINAL_APP_URL\x10\x1b\x12 \n\x1cINVALID_TAG_IN_FINAL_APP_URL\x10\x1c\x12&\n\"REDUNDANT_NESTED_FINAL_APP_URL_TAG\x10\x1d\x12 \n\x1cMULTIPLE_APP_URLS_FOR_OSTYPE\x10\x1e\x12\x12\n\x0eINVALID_OSTYPE\x10\x1f\x12 \n\x1cINVALID_PROTOCOL_FOR_APP_URL\x10 \x12\"\n\x1eINVALID_PACKAGE_ID_FOR_APP_URL\x10!\x12-\n)URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT\x10\"\x12\x32\n.INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY\x10\'\x12\x34\n0INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE\x10(\x12-\n)INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE\x10)\x12-\n)REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG\x10*\x12\x14\n\x10MISSING_PROTOCOL\x10+\x12\x14\n\x10INVALID_PROTOCOL\x10\x34\x12\x0f\n\x0bINVALID_URL\x10,\x12\x1e\n\x1a\x44\x45STINATION_URL_DEPRECATED\x10-\x12\x16\n\x12INVALID_TAG_IN_URL\x10.\x12\x13\n\x0fMISSING_URL_TAG\x10/\x12\x14\n\x10\x44UPLICATE_URL_ID\x10\x30\x12\x12\n\x0eINVALID_URL_ID\x10\x31\x12\x1e\n\x1a\x46INAL_URL_SUFFIX_MALFORMED\x10\x32\x12#\n\x1fINVALID_TAG_IN_FINAL_URL_SUFFIX\x10\x33\x12\x1c\n\x18INVALID_TOP_LEVEL_DOMAIN\x10\x35\x12\x1e\n\x1aMALFORMED_TOP_LEVEL_DOMAIN\x10\x36\x12\x11\n\rMALFORMED_URL\x10\x37\x12\x10\n\x0cMISSING_HOST\x10\x38\x12\x1f\n\x1bNULL_CUSTOM_PARAMETER_VALUE\x10\x39\x42\xed\x01\n\"com.google.ads.googleads.v2.errorsB\x12UrlFieldErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_URLFIELDERRORENUM_URLFIELDERROR = _descriptor.EnumDescriptor(
  name='UrlFieldError',
  full_name='google.ads.googleads.v2.errors.UrlFieldErrorEnum.UrlFieldError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TRACKING_URL_TEMPLATE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TAG_IN_TRACKING_URL_TEMPLATE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_TRACKING_URL_TEMPLATE_TAG', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALFORMED_TRACKING_URL_TEMPLATE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_HOST_IN_TRACKING_URL_TEMPLATE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TLD_IN_TRACKING_URL_TEMPLATE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FINAL_URL', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TAG_IN_FINAL_URL', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDUNDANT_NESTED_FINAL_URL_TAG', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_PROTOCOL_IN_FINAL_URL', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PROTOCOL_IN_FINAL_URL', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALFORMED_FINAL_URL', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_HOST_IN_FINAL_URL', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TLD_IN_FINAL_URL', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FINAL_MOBILE_URL', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TAG_IN_FINAL_MOBILE_URL', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_PROTOCOL_IN_FINAL_MOBILE_URL', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PROTOCOL_IN_FINAL_MOBILE_URL', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALFORMED_FINAL_MOBILE_URL', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_HOST_IN_FINAL_MOBILE_URL', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TLD_IN_FINAL_MOBILE_URL', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FINAL_APP_URL', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TAG_IN_FINAL_APP_URL', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDUNDANT_NESTED_FINAL_APP_URL_TAG', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLE_APP_URLS_FOR_OSTYPE', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_OSTYPE', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PROTOCOL_FOR_APP_URL', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PACKAGE_ID_FOR_APP_URL', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY', index=35, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE', index=36, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE', index=37, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG', index=38, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_PROTOCOL', index=39, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PROTOCOL', index=40, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_URL', index=41, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESTINATION_URL_DEPRECATED', index=42, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TAG_IN_URL', index=43, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_URL_TAG', index=44, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_URL_ID', index=45, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_URL_ID', index=46, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URL_SUFFIX_MALFORMED', index=47, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TAG_IN_FINAL_URL_SUFFIX', index=48, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TOP_LEVEL_DOMAIN', index=49, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALFORMED_TOP_LEVEL_DOMAIN', index=50, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALFORMED_URL', index=51, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_HOST', index=52, number=56,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NULL_CUSTOM_PARAMETER_VALUE', index=53, number=57,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=147,
  serialized_end=1971,
)
_sym_db.RegisterEnumDescriptor(_URLFIELDERRORENUM_URLFIELDERROR)


_URLFIELDERRORENUM = _descriptor.Descriptor(
  name='UrlFieldErrorEnum',
  full_name='google.ads.googleads.v2.errors.UrlFieldErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _URLFIELDERRORENUM_URLFIELDERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=1971,
)

_URLFIELDERRORENUM_URLFIELDERROR.containing_type = _URLFIELDERRORENUM
DESCRIPTOR.message_types_by_name['UrlFieldErrorEnum'] = _URLFIELDERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UrlFieldErrorEnum = _reflection.GeneratedProtocolMessageType('UrlFieldErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _URLFIELDERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.url_field_error_pb2'
  ,
  __doc__ = """Container for enum describing possible url field errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.UrlFieldErrorEnum)
  ))
_sym_db.RegisterMessage(UrlFieldErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Common utilities for the Google Ads API client library."""

import functools
import re

# This regex matches characters preceded by start of line or an underscore.
_RE_FIND_CHARS_TO_UPPERCASE = re.compile(r'(?:_|^)([a-z])')


class ResourceName:

    # As of Google Ads API v1 composite resource names are
    # delimited by a "~" character.
    _COMPOSITE_DELIMITER = '~'

    @classmethod
    def format_composite(cls, *arg):
        """Formats any number of ID strings into a single composite string.

        Note: this utility does not construct an entire resource name string.
        It only formats the composite portion for IDs that are not globally
        unique, for example an ad_group_ad.

        Args:
            arg: Any number of str IDs for resources such as ad_groups or
            ad_group_ads.

        Returns:
            A str of all the given strs concatenated with the compsite
            delimiter.

        Raises:
           TypeError: If anything other than a string is passed in.
        """
        return cls._COMPOSITE_DELIMITER.join(arg)


def get_nested_attr(obj, attr, *args):
    """Gets the value of a nested attribute from an object.

    Args:
      obj: an object to retrieve an attribute value from.
      attr: a string of the attribute separated by dots.

    Returns:
      The object attribute value or the given *args if the attr isn't present.
    """
    def _getattr(obj, attr):
        return getattr(obj, attr, *args)

    return functools.reduce(_getattr, [obj] + attr.split('.'))


def convert_upper_case_to_snake_case(string):
    """Converts a string from UpperCase to snake_case.

    Primarily used to translate module names when retrieving them from version
    modules' __init__.py files.

    Args:
        string: an arbitrary string to convert.
    """
    new_string = ''
    index = 0

    for char in string:
        if index == 0:
            new_string += char.lower()
        elif char.isupper():
            new_string += f'_{char.lower()}'
        else:
            new_string += char

        index += 1

    return new_string


def convert_snake_case_to_upper_case(string):
    """Converts a string from snake_case to UpperCase.

    Primarily used to translate module names when retrieving them from version
    modules' __init__.py files.

    Args:
        string: an arbitrary string to convert.
    """
    def converter(match):
        """Convert a string to strip underscores then uppercase it."""
        return match.group().replace('_', '').upper()

    return _RE_FIND_CHARS_TO_UPPERCASE.sub(converter, string)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/real_time_bidding_setting.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/real_time_bidding_setting.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\033RealTimeBiddingSettingProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\nDgoogle/ads/googleads_v1/proto/common/real_time_bidding_setting.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"D\n\x16RealTimeBiddingSetting\x12*\n\x06opt_in\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\xf6\x01\n\"com.google.ads.googleads.v1.commonB\x1bRealTimeBiddingSettingProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_REALTIMEBIDDINGSETTING = _descriptor.Descriptor(
  name='RealTimeBiddingSetting',
  full_name='google.ads.googleads.v1.common.RealTimeBiddingSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='opt_in', full_name='google.ads.googleads.v1.common.RealTimeBiddingSetting.opt_in', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=234,
)

_REALTIMEBIDDINGSETTING.fields_by_name['opt_in'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
DESCRIPTOR.message_types_by_name['RealTimeBiddingSetting'] = _REALTIMEBIDDINGSETTING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RealTimeBiddingSetting = _reflection.GeneratedProtocolMessageType('RealTimeBiddingSetting', (_message.Message,), dict(
  DESCRIPTOR = _REALTIMEBIDDINGSETTING,
  __module__ = 'google.ads.googleads_v1.proto.common.real_time_bidding_setting_pb2'
  ,
  __doc__ = """Settings for Real-Time Bidding, a feature only available for campaigns
  targeting the Ad Exchange network.
  
  
  Attributes:
      opt_in:
          Whether the campaign is opted in to real-time bidding.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.RealTimeBiddingSetting)
  ))
_sym_db.RegisterMessage(RealTimeBiddingSetting)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/query_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/query_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\017QueryErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n6google/ads/googleads_v1/proto/errors/query_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xb8\r\n\x0eQueryErrorEnum\"\xa5\r\n\nQueryError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0f\n\x0bQUERY_ERROR\x10\x32\x12\x15\n\x11\x42\x41\x44_ENUM_CONSTANT\x10\x12\x12\x17\n\x13\x42\x41\x44_ESCAPE_SEQUENCE\x10\x07\x12\x12\n\x0e\x42\x41\x44_FIELD_NAME\x10\x0c\x12\x13\n\x0f\x42\x41\x44_LIMIT_VALUE\x10\x0f\x12\x0e\n\nBAD_NUMBER\x10\x05\x12\x10\n\x0c\x42\x41\x44_OPERATOR\x10\x03\x12\x16\n\x12\x42\x41\x44_PARAMETER_NAME\x10=\x12\x17\n\x13\x42\x41\x44_PARAMETER_VALUE\x10>\x12$\n BAD_RESOURCE_TYPE_IN_FROM_CLAUSE\x10-\x12\x0e\n\nBAD_SYMBOL\x10\x02\x12\r\n\tBAD_VALUE\x10\x04\x12\x17\n\x13\x44\x41TE_RANGE_TOO_WIDE\x10$\x12\x10\n\x0c\x45XPECTED_AND\x10\x1e\x12\x0f\n\x0b\x45XPECTED_BY\x10\x0e\x12-\n)EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE\x10%\x12\"\n\x1e\x45XPECTED_FILTERS_ON_DATE_RANGE\x10\x37\x12\x11\n\rEXPECTED_FROM\x10,\x12\x11\n\rEXPECTED_LIST\x10)\x12.\n*EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE\x10\x10\x12\x13\n\x0f\x45XPECTED_SELECT\x10\r\x12\x19\n\x15\x45XPECTED_SINGLE_VALUE\x10*\x12(\n$EXPECTED_VALUE_WITH_BETWEEN_OPERATOR\x10\x1d\x12\x17\n\x13INVALID_DATE_FORMAT\x10&\x12\x18\n\x14INVALID_STRING_VALUE\x10\x39\x12\'\n#INVALID_VALUE_WITH_BETWEEN_OPERATOR\x10\x1a\x12&\n\"INVALID_VALUE_WITH_DURING_OPERATOR\x10\x16\x12$\n INVALID_VALUE_WITH_LIKE_OPERATOR\x10\x38\x12\x1b\n\x17OPERATOR_FIELD_MISMATCH\x10#\x12&\n\"PROHIBITED_EMPTY_LIST_IN_CONDITION\x10\x1c\x12\x1c\n\x18PROHIBITED_ENUM_CONSTANT\x10\x36\x12\x31\n-PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE\x10\x1f\x12\'\n#PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE\x10(\x12%\n!PROHIBITED_FIELD_IN_SELECT_CLAUSE\x10\x17\x12$\n PROHIBITED_FIELD_IN_WHERE_CLAUSE\x10\x18\x12+\n\'PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE\x10+\x12-\n)PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE\x10\x30\x12,\n(PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE\x10:\x12/\n+PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE\x10\x31\x12\x30\n,PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE\x10\x33\x12<\n8PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE\x10\x35\x12\x17\n\x13LIMIT_VALUE_TOO_LOW\x10\x19\x12 \n\x1cPROHIBITED_NEWLINE_IN_STRING\x10\x08\x12(\n$PROHIBITED_VALUE_COMBINATION_IN_LIST\x10\n\x12\x36\n2PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR\x10\x15\x12\x19\n\x15STRING_NOT_TERMINATED\x10\x06\x12\x15\n\x11TOO_MANY_SEGMENTS\x10\"\x12\x1b\n\x17UNEXPECTED_END_OF_QUERY\x10\t\x12\x1a\n\x16UNEXPECTED_FROM_CLAUSE\x10/\x12\x16\n\x12UNRECOGNIZED_FIELD\x10 \x12\x14\n\x10UNEXPECTED_INPUT\x10\x0b\x12!\n\x1dREQUESTED_METRICS_FOR_MANAGER\x10;B\xea\x01\n\"com.google.ads.googleads.v1.errorsB\x0fQueryErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_QUERYERRORENUM_QUERYERROR = _descriptor.EnumDescriptor(
  name='QueryError',
  full_name='google.ads.googleads.v1.errors.QueryErrorEnum.QueryError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY_ERROR', index=2, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_ENUM_CONSTANT', index=3, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_ESCAPE_SEQUENCE', index=4, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_FIELD_NAME', index=5, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_LIMIT_VALUE', index=6, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_NUMBER', index=7, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_OPERATOR', index=8, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_PARAMETER_NAME', index=9, number=61,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_PARAMETER_VALUE', index=10, number=62,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_RESOURCE_TYPE_IN_FROM_CLAUSE', index=11, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_SYMBOL', index=12, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_VALUE', index=13, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_RANGE_TOO_WIDE', index=14, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_AND', index=15, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_BY', index=16, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE', index=17, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_FILTERS_ON_DATE_RANGE', index=18, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_FROM', index=19, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_LIST', index=20, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE', index=21, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_SELECT', index=22, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_SINGLE_VALUE', index=23, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPECTED_VALUE_WITH_BETWEEN_OPERATOR', index=24, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DATE_FORMAT', index=25, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STRING_VALUE', index=26, number=57,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_VALUE_WITH_BETWEEN_OPERATOR', index=27, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_VALUE_WITH_DURING_OPERATOR', index=28, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_VALUE_WITH_LIKE_OPERATOR', index=29, number=56,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATOR_FIELD_MISMATCH', index=30, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_EMPTY_LIST_IN_CONDITION', index=31, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_ENUM_CONSTANT', index=32, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE', index=33, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE', index=34, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_FIELD_IN_SELECT_CLAUSE', index=35, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_FIELD_IN_WHERE_CLAUSE', index=36, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE', index=37, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE', index=38, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE', index=39, number=58,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE', index=40, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE', index=41, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE', index=42, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIMIT_VALUE_TOO_LOW', index=43, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_NEWLINE_IN_STRING', index=44, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_VALUE_COMBINATION_IN_LIST', index=45, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR', index=46, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING_NOT_TERMINATED', index=47, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_SEGMENTS', index=48, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNEXPECTED_END_OF_QUERY', index=49, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNEXPECTED_FROM_CLAUSE', index=50, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNRECOGNIZED_FIELD', index=51, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNEXPECTED_INPUT', index=52, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUESTED_METRICS_FOR_MANAGER', index=53, number=59,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=140,
  serialized_end=1841,
)
_sym_db.RegisterEnumDescriptor(_QUERYERRORENUM_QUERYERROR)


_QUERYERRORENUM = _descriptor.Descriptor(
  name='QueryErrorEnum',
  full_name='google.ads.googleads.v1.errors.QueryErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _QUERYERRORENUM_QUERYERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=1841,
)

_QUERYERRORENUM_QUERYERROR.containing_type = _QUERYERRORENUM
DESCRIPTOR.message_types_by_name['QueryErrorEnum'] = _QUERYERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryErrorEnum = _reflection.GeneratedProtocolMessageType('QueryErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _QUERYERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.query_error_pb2'
  ,
  __doc__ = """Container for enum describing possible query errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.QueryErrorEnum)
  ))
_sym_db.RegisterMessage(QueryErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/customer_label_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import customer_label_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__label__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/customer_label_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\031CustomerLabelServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v1/proto/services/customer_label_service.proto\x12 google.ads.googleads.v1.services\x1a<google/ads/googleads_v1/proto/resources/customer_label.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\"0\n\x17GetCustomerLabelRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xb0\x01\n\x1bMutateCustomerLabelsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12L\n\noperations\x18\x02 \x03(\x0b\x32\x38.google.ads.googleads.v1.services.CustomerLabelOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"{\n\x16\x43ustomerLabelOperation\x12\x42\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v1.resources.CustomerLabelH\x00\x12\x10\n\x06remove\x18\x02 \x01(\tH\x00\x42\x0b\n\toperation\"\x9f\x01\n\x1cMutateCustomerLabelsResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12L\n\x07results\x18\x02 \x03(\x0b\x32;.google.ads.googleads.v1.services.MutateCustomerLabelResult\"2\n\x19MutateCustomerLabelResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xaa\x03\n\x14\x43ustomerLabelService\x12\xb9\x01\n\x10GetCustomerLabel\x12\x39.google.ads.googleads.v1.services.GetCustomerLabelRequest\x1a\x30.google.ads.googleads.v1.resources.CustomerLabel\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v1/{resource_name=customers/*/customerLabels/*}\x12\xd5\x01\n\x14MutateCustomerLabels\x12=.google.ads.googleads.v1.services.MutateCustomerLabelsRequest\x1a>.google.ads.googleads.v1.services.MutateCustomerLabelsResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v1/customers/{customer_id=*}/customerLabels:mutate:\x01*B\x80\x02\n$com.google.ads.googleads.v1.servicesB\x19\x43ustomerLabelServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__label__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_GETCUSTOMERLABELREQUEST = _descriptor.Descriptor(
  name='GetCustomerLabelRequest',
  full_name='google.ads.googleads.v1.services.GetCustomerLabelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetCustomerLabelRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=302,
)


_MUTATECUSTOMERLABELSREQUEST = _descriptor.Descriptor(
  name='MutateCustomerLabelsRequest',
  full_name='google.ads.googleads.v1.services.MutateCustomerLabelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.MutateCustomerLabelsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.MutateCustomerLabelsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v1.services.MutateCustomerLabelsRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v1.services.MutateCustomerLabelsRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=481,
)


_CUSTOMERLABELOPERATION = _descriptor.Descriptor(
  name='CustomerLabelOperation',
  full_name='google.ads.googleads.v1.services.CustomerLabelOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v1.services.CustomerLabelOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v1.services.CustomerLabelOperation.remove', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.CustomerLabelOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=483,
  serialized_end=606,
)


_MUTATECUSTOMERLABELSRESPONSE = _descriptor.Descriptor(
  name='MutateCustomerLabelsResponse',
  full_name='google.ads.googleads.v1.services.MutateCustomerLabelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v1.services.MutateCustomerLabelsResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.MutateCustomerLabelsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=768,
)


_MUTATECUSTOMERLABELRESULT = _descriptor.Descriptor(
  name='MutateCustomerLabelResult',
  full_name='google.ads.googleads.v1.services.MutateCustomerLabelResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.MutateCustomerLabelResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=820,
)

_MUTATECUSTOMERLABELSREQUEST.fields_by_name['operations'].message_type = _CUSTOMERLABELOPERATION
_CUSTOMERLABELOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__label__pb2._CUSTOMERLABEL
_CUSTOMERLABELOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMERLABELOPERATION.fields_by_name['create'])
_CUSTOMERLABELOPERATION.fields_by_name['create'].containing_oneof = _CUSTOMERLABELOPERATION.oneofs_by_name['operation']
_CUSTOMERLABELOPERATION.oneofs_by_name['operation'].fields.append(
  _CUSTOMERLABELOPERATION.fields_by_name['remove'])
_CUSTOMERLABELOPERATION.fields_by_name['remove'].containing_oneof = _CUSTOMERLABELOPERATION.oneofs_by_name['operation']
_MUTATECUSTOMERLABELSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATECUSTOMERLABELSRESPONSE.fields_by_name['results'].message_type = _MUTATECUSTOMERLABELRESULT
DESCRIPTOR.message_types_by_name['GetCustomerLabelRequest'] = _GETCUSTOMERLABELREQUEST
DESCRIPTOR.message_types_by_name['MutateCustomerLabelsRequest'] = _MUTATECUSTOMERLABELSREQUEST
DESCRIPTOR.message_types_by_name['CustomerLabelOperation'] = _CUSTOMERLABELOPERATION
DESCRIPTOR.message_types_by_name['MutateCustomerLabelsResponse'] = _MUTATECUSTOMERLABELSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCustomerLabelResult'] = _MUTATECUSTOMERLABELRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCustomerLabelRequest = _reflection.GeneratedProtocolMessageType('GetCustomerLabelRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCUSTOMERLABELREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_label_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerLabelService.GetCustomerLabel][google.ads.googleads.v1.services.CustomerLabelService.GetCustomerLabel].
  
  
  Attributes:
      resource_name:
          The resource name of the customer-label relationship to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetCustomerLabelRequest)
  ))
_sym_db.RegisterMessage(GetCustomerLabelRequest)

MutateCustomerLabelsRequest = _reflection.GeneratedProtocolMessageType('MutateCustomerLabelsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERLABELSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_label_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerLabelService.MutateCustomerLabels][google.ads.googleads.v1.services.CustomerLabelService.MutateCustomerLabels].
  
  
  Attributes:
      customer_id:
          ID of the customer whose customer-label relationships are
          being modified.
      operations:
          The list of operations to perform on customer-label
          relationships.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomerLabelsRequest)
  ))
_sym_db.RegisterMessage(MutateCustomerLabelsRequest)

CustomerLabelOperation = _reflection.GeneratedProtocolMessageType('CustomerLabelOperation', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMERLABELOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_label_service_pb2'
  ,
  __doc__ = """A single operation (create, remove) on a customer-label relationship.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          customer-label relationship.
      remove:
          Remove operation: A resource name for the customer-label
          relationship being removed, in this format:
          ``customers/{customer_id}/customerLabels/{label_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.CustomerLabelOperation)
  ))
_sym_db.RegisterMessage(CustomerLabelOperation)

MutateCustomerLabelsResponse = _reflection.GeneratedProtocolMessageType('MutateCustomerLabelsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERLABELSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_label_service_pb2'
  ,
  __doc__ = """Response message for a customer labels mutate.
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors), we return an RPC
          level error.
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomerLabelsResponse)
  ))
_sym_db.RegisterMessage(MutateCustomerLabelsResponse)

MutateCustomerLabelResult = _reflection.GeneratedProtocolMessageType('MutateCustomerLabelResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERLABELRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.customer_label_service_pb2'
  ,
  __doc__ = """The result for a customer label mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCustomerLabelResult)
  ))
_sym_db.RegisterMessage(MutateCustomerLabelResult)


DESCRIPTOR._options = None

_CUSTOMERLABELSERVICE = _descriptor.ServiceDescriptor(
  name='CustomerLabelService',
  full_name='google.ads.googleads.v1.services.CustomerLabelService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=823,
  serialized_end=1249,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCustomerLabel',
    full_name='google.ads.googleads.v1.services.CustomerLabelService.GetCustomerLabel',
    index=0,
    containing_service=None,
    input_type=_GETCUSTOMERLABELREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__label__pb2._CUSTOMERLABEL,
    serialized_options=_b('\202\323\344\223\0022\0220/v1/{resource_name=customers/*/customerLabels/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCustomerLabels',
    full_name='google.ads.googleads.v1.services.CustomerLabelService.MutateCustomerLabels',
    index=1,
    containing_service=None,
    input_type=_MUTATECUSTOMERLABELSREQUEST,
    output_type=_MUTATECUSTOMERLABELSRESPONSE,
    serialized_options=_b('\202\323\344\223\0028\"3/v1/customers/{customer_id=*}/customerLabels:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CUSTOMERLABELSERVICE)

DESCRIPTOR.services_by_name['CustomerLabelService'] = _CUSTOMERLABELSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/customer_feed.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import matching_function_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_matching__function__pb2
from google.ads.google_ads.v1.proto.enums import feed_link_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_feed__link__status__pb2
from google.ads.google_ads.v1.proto.enums import placeholder_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_placeholder__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/customer_feed.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\021CustomerFeedProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n;google/ads/googleads_v1/proto/resources/customer_feed.proto\x12!google.ads.googleads.v1.resources\x1a<google/ads/googleads_v1/proto/common/matching_function.proto\x1a:google/ads/googleads_v1/proto/enums/feed_link_status.proto\x1a:google/ads/googleads_v1/proto/enums/placeholder_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xcf\x02\n\x0c\x43ustomerFeed\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12*\n\x04\x66\x65\x65\x64\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12]\n\x11placeholder_types\x18\x03 \x03(\x0e\x32\x42.google.ads.googleads.v1.enums.PlaceholderTypeEnum.PlaceholderType\x12K\n\x11matching_function\x18\x04 \x01(\x0b\x32\x30.google.ads.googleads.v1.common.MatchingFunction\x12P\n\x06status\x18\x05 \x01(\x0e\x32@.google.ads.googleads.v1.enums.FeedLinkStatusEnum.FeedLinkStatusB\xfe\x01\n%com.google.ads.googleads.v1.resourcesB\x11\x43ustomerFeedProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_matching__function__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_feed__link__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_placeholder__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CUSTOMERFEED = _descriptor.Descriptor(
  name='CustomerFeed',
  full_name='google.ads.googleads.v1.resources.CustomerFeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.CustomerFeed.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed', full_name='google.ads.googleads.v1.resources.CustomerFeed.feed', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_types', full_name='google.ads.googleads.v1.resources.CustomerFeed.placeholder_types', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matching_function', full_name='google.ads.googleads.v1.resources.CustomerFeed.matching_function', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.CustomerFeed.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=678,
)

_CUSTOMERFEED.fields_by_name['feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMERFEED.fields_by_name['placeholder_types'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_placeholder__type__pb2._PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE
_CUSTOMERFEED.fields_by_name['matching_function'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_matching__function__pb2._MATCHINGFUNCTION
_CUSTOMERFEED.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_feed__link__status__pb2._FEEDLINKSTATUSENUM_FEEDLINKSTATUS
DESCRIPTOR.message_types_by_name['CustomerFeed'] = _CUSTOMERFEED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustomerFeed = _reflection.GeneratedProtocolMessageType('CustomerFeed', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMERFEED,
  __module__ = 'google.ads.googleads_v1.proto.resources.customer_feed_pb2'
  ,
  __doc__ = """A customer feed.
  
  
  Attributes:
      resource_name:
          The resource name of the customer feed. Customer feed resource
          names have the form:
          ``customers/{customer_id}/customerFeeds/{feed_id}``
      feed:
          The feed being linked to the customer.
      placeholder_types:
          Indicates which placeholder types the feed may populate under
          the connected customer. Required.
      matching_function:
          Matching function associated with the CustomerFeed. The
          matching function is used to filter the set of feed items
          selected. Required.
      status:
          Status of the customer feed. This field is read-only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.CustomerFeed)
  ))
_sym_db.RegisterMessage(CustomerFeed)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/campaign_criterion.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v2.proto.enums import campaign_criterion_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__criterion__status__pb2
from google.ads.google_ads.v2.proto.enums import criterion_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/campaign_criterion.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\026CampaignCriterionProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n@google/ads/googleads_v2/proto/resources/campaign_criterion.proto\x12!google.ads.googleads.v2.resources\x1a\x33google/ads/googleads_v2/proto/common/criteria.proto\x1a\x43google/ads/googleads_v2/proto/enums/campaign_criterion_status.proto\x1a\x38google/ads/googleads_v2/proto/enums/criterion_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xc4\x12\n\x11\x43\x61mpaignCriterion\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12.\n\x08\x63\x61mpaign\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0c\x63riterion_id\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0c\x62id_modifier\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12,\n\x08negative\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n\x04type\x18\x06 \x01(\x0e\x32>.google.ads.googleads.v2.enums.CriterionTypeEnum.CriterionType\x12\x62\n\x06status\x18# \x01(\x0e\x32R.google.ads.googleads.v2.enums.CampaignCriterionStatusEnum.CampaignCriterionStatus\x12>\n\x07keyword\x18\x08 \x01(\x0b\x32+.google.ads.googleads.v2.common.KeywordInfoH\x00\x12\x42\n\tplacement\x18\t \x01(\x0b\x32-.google.ads.googleads.v2.common.PlacementInfoH\x00\x12T\n\x13mobile_app_category\x18\n \x01(\x0b\x32\x35.google.ads.googleads.v2.common.MobileAppCategoryInfoH\x00\x12S\n\x12mobile_application\x18\x0b \x01(\x0b\x32\x35.google.ads.googleads.v2.common.MobileApplicationInfoH\x00\x12@\n\x08location\x18\x0c \x01(\x0b\x32,.google.ads.googleads.v2.common.LocationInfoH\x00\x12<\n\x06\x64\x65vice\x18\r \x01(\x0b\x32*.google.ads.googleads.v2.common.DeviceInfoH\x00\x12\x45\n\x0b\x61\x64_schedule\x18\x0f \x01(\x0b\x32..google.ads.googleads.v2.common.AdScheduleInfoH\x00\x12\x41\n\tage_range\x18\x10 \x01(\x0b\x32,.google.ads.googleads.v2.common.AgeRangeInfoH\x00\x12<\n\x06gender\x18\x11 \x01(\x0b\x32*.google.ads.googleads.v2.common.GenderInfoH\x00\x12G\n\x0cincome_range\x18\x12 \x01(\x0b\x32/.google.ads.googleads.v2.common.IncomeRangeInfoH\x00\x12M\n\x0fparental_status\x18\x13 \x01(\x0b\x32\x32.google.ads.googleads.v2.common.ParentalStatusInfoH\x00\x12\x41\n\tuser_list\x18\x16 \x01(\x0b\x32,.google.ads.googleads.v2.common.UserListInfoH\x00\x12I\n\ryoutube_video\x18\x14 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.YouTubeVideoInfoH\x00\x12M\n\x0fyoutube_channel\x18\x15 \x01(\x0b\x32\x32.google.ads.googleads.v2.common.YouTubeChannelInfoH\x00\x12\x42\n\tproximity\x18\x17 \x01(\x0b\x32-.google.ads.googleads.v2.common.ProximityInfoH\x00\x12:\n\x05topic\x18\x18 \x01(\x0b\x32).google.ads.googleads.v2.common.TopicInfoH\x00\x12I\n\rlisting_scope\x18\x19 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.ListingScopeInfoH\x00\x12@\n\x08language\x18\x1a \x01(\x0b\x32,.google.ads.googleads.v2.common.LanguageInfoH\x00\x12?\n\x08ip_block\x18\x1b \x01(\x0b\x32+.google.ads.googleads.v2.common.IpBlockInfoH\x00\x12I\n\rcontent_label\x18\x1c \x01(\x0b\x32\x30.google.ads.googleads.v2.common.ContentLabelInfoH\x00\x12>\n\x07\x63\x61rrier\x18\x1d \x01(\x0b\x32+.google.ads.googleads.v2.common.CarrierInfoH\x00\x12I\n\ruser_interest\x18\x1e \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserInterestInfoH\x00\x12>\n\x07webpage\x18\x1f \x01(\x0b\x32+.google.ads.googleads.v2.common.WebpageInfoH\x00\x12^\n\x18operating_system_version\x18  \x01(\x0b\x32:.google.ads.googleads.v2.common.OperatingSystemVersionInfoH\x00\x12I\n\rmobile_device\x18! \x01(\x0b\x32\x30.google.ads.googleads.v2.common.MobileDeviceInfoH\x00\x12K\n\x0elocation_group\x18\" \x01(\x0b\x32\x31.google.ads.googleads.v2.common.LocationGroupInfoH\x00\x12M\n\x0f\x63ustom_affinity\x18$ \x01(\x0b\x32\x32.google.ads.googleads.v2.common.CustomAffinityInfoH\x00\x42\x0b\n\tcriterionB\x83\x02\n%com.google.ads.googleads.v2.resourcesB\x16\x43\x61mpaignCriterionProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__criterion__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNCRITERION = _descriptor.Descriptor(
  name='CampaignCriterion',
  full_name='google.ads.googleads.v2.resources.CampaignCriterion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.CampaignCriterion.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v2.resources.CampaignCriterion.campaign', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_id', full_name='google.ads.googleads.v2.resources.CampaignCriterion.criterion_id', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid_modifier', full_name='google.ads.googleads.v2.resources.CampaignCriterion.bid_modifier', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negative', full_name='google.ads.googleads.v2.resources.CampaignCriterion.negative', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.CampaignCriterion.type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.CampaignCriterion.status', index=6,
      number=35, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v2.resources.CampaignCriterion.keyword', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement', full_name='google.ads.googleads.v2.resources.CampaignCriterion.placement', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_app_category', full_name='google.ads.googleads.v2.resources.CampaignCriterion.mobile_app_category', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_application', full_name='google.ads.googleads.v2.resources.CampaignCriterion.mobile_application', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='google.ads.googleads.v2.resources.CampaignCriterion.location', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='google.ads.googleads.v2.resources.CampaignCriterion.device', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_schedule', full_name='google.ads.googleads.v2.resources.CampaignCriterion.ad_schedule', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='age_range', full_name='google.ads.googleads.v2.resources.CampaignCriterion.age_range', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gender', full_name='google.ads.googleads.v2.resources.CampaignCriterion.gender', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='income_range', full_name='google.ads.googleads.v2.resources.CampaignCriterion.income_range', index=16,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parental_status', full_name='google.ads.googleads.v2.resources.CampaignCriterion.parental_status', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_list', full_name='google.ads.googleads.v2.resources.CampaignCriterion.user_list', index=18,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_video', full_name='google.ads.googleads.v2.resources.CampaignCriterion.youtube_video', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_channel', full_name='google.ads.googleads.v2.resources.CampaignCriterion.youtube_channel', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proximity', full_name='google.ads.googleads.v2.resources.CampaignCriterion.proximity', index=21,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic', full_name='google.ads.googleads.v2.resources.CampaignCriterion.topic', index=22,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listing_scope', full_name='google.ads.googleads.v2.resources.CampaignCriterion.listing_scope', index=23,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='google.ads.googleads.v2.resources.CampaignCriterion.language', index=24,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_block', full_name='google.ads.googleads.v2.resources.CampaignCriterion.ip_block', index=25,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_label', full_name='google.ads.googleads.v2.resources.CampaignCriterion.content_label', index=26,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='carrier', full_name='google.ads.googleads.v2.resources.CampaignCriterion.carrier', index=27,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_interest', full_name='google.ads.googleads.v2.resources.CampaignCriterion.user_interest', index=28,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='webpage', full_name='google.ads.googleads.v2.resources.CampaignCriterion.webpage', index=29,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operating_system_version', full_name='google.ads.googleads.v2.resources.CampaignCriterion.operating_system_version', index=30,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_device', full_name='google.ads.googleads.v2.resources.CampaignCriterion.mobile_device', index=31,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_group', full_name='google.ads.googleads.v2.resources.CampaignCriterion.location_group', index=32,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_affinity', full_name='google.ads.googleads.v2.resources.CampaignCriterion.custom_affinity', index=33,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='criterion', full_name='google.ads.googleads.v2.resources.CampaignCriterion.criterion',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=346,
  serialized_end=2718,
)

_CAMPAIGNCRITERION.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNCRITERION.fields_by_name['criterion_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNCRITERION.fields_by_name['bid_modifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_CAMPAIGNCRITERION.fields_by_name['negative'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGNCRITERION.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2._CRITERIONTYPEENUM_CRITERIONTYPE
_CAMPAIGNCRITERION.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_campaign__criterion__status__pb2._CAMPAIGNCRITERIONSTATUSENUM_CAMPAIGNCRITERIONSTATUS
_CAMPAIGNCRITERION.fields_by_name['keyword'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._KEYWORDINFO
_CAMPAIGNCRITERION.fields_by_name['placement'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._PLACEMENTINFO
_CAMPAIGNCRITERION.fields_by_name['mobile_app_category'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._MOBILEAPPCATEGORYINFO
_CAMPAIGNCRITERION.fields_by_name['mobile_application'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._MOBILEAPPLICATIONINFO
_CAMPAIGNCRITERION.fields_by_name['location'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._LOCATIONINFO
_CAMPAIGNCRITERION.fields_by_name['device'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._DEVICEINFO
_CAMPAIGNCRITERION.fields_by_name['ad_schedule'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._ADSCHEDULEINFO
_CAMPAIGNCRITERION.fields_by_name['age_range'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._AGERANGEINFO
_CAMPAIGNCRITERION.fields_by_name['gender'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._GENDERINFO
_CAMPAIGNCRITERION.fields_by_name['income_range'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._INCOMERANGEINFO
_CAMPAIGNCRITERION.fields_by_name['parental_status'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._PARENTALSTATUSINFO
_CAMPAIGNCRITERION.fields_by_name['user_list'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._USERLISTINFO
_CAMPAIGNCRITERION.fields_by_name['youtube_video'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._YOUTUBEVIDEOINFO
_CAMPAIGNCRITERION.fields_by_name['youtube_channel'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._YOUTUBECHANNELINFO
_CAMPAIGNCRITERION.fields_by_name['proximity'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._PROXIMITYINFO
_CAMPAIGNCRITERION.fields_by_name['topic'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._TOPICINFO
_CAMPAIGNCRITERION.fields_by_name['listing_scope'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._LISTINGSCOPEINFO
_CAMPAIGNCRITERION.fields_by_name['language'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._LANGUAGEINFO
_CAMPAIGNCRITERION.fields_by_name['ip_block'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._IPBLOCKINFO
_CAMPAIGNCRITERION.fields_by_name['content_label'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._CONTENTLABELINFO
_CAMPAIGNCRITERION.fields_by_name['carrier'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._CARRIERINFO
_CAMPAIGNCRITERION.fields_by_name['user_interest'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._USERINTERESTINFO
_CAMPAIGNCRITERION.fields_by_name['webpage'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._WEBPAGEINFO
_CAMPAIGNCRITERION.fields_by_name['operating_system_version'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._OPERATINGSYSTEMVERSIONINFO
_CAMPAIGNCRITERION.fields_by_name['mobile_device'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._MOBILEDEVICEINFO
_CAMPAIGNCRITERION.fields_by_name['location_group'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._LOCATIONGROUPINFO
_CAMPAIGNCRITERION.fields_by_name['custom_affinity'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._CUSTOMAFFINITYINFO
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['keyword'])
_CAMPAIGNCRITERION.fields_by_name['keyword'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['placement'])
_CAMPAIGNCRITERION.fields_by_name['placement'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['mobile_app_category'])
_CAMPAIGNCRITERION.fields_by_name['mobile_app_category'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['mobile_application'])
_CAMPAIGNCRITERION.fields_by_name['mobile_application'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['location'])
_CAMPAIGNCRITERION.fields_by_name['location'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['device'])
_CAMPAIGNCRITERION.fields_by_name['device'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['ad_schedule'])
_CAMPAIGNCRITERION.fields_by_name['ad_schedule'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['age_range'])
_CAMPAIGNCRITERION.fields_by_name['age_range'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['gender'])
_CAMPAIGNCRITERION.fields_by_name['gender'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['income_range'])
_CAMPAIGNCRITERION.fields_by_name['income_range'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['parental_status'])
_CAMPAIGNCRITERION.fields_by_name['parental_status'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['user_list'])
_CAMPAIGNCRITERION.fields_by_name['user_list'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['youtube_video'])
_CAMPAIGNCRITERION.fields_by_name['youtube_video'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['youtube_channel'])
_CAMPAIGNCRITERION.fields_by_name['youtube_channel'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['proximity'])
_CAMPAIGNCRITERION.fields_by_name['proximity'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['topic'])
_CAMPAIGNCRITERION.fields_by_name['topic'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['listing_scope'])
_CAMPAIGNCRITERION.fields_by_name['listing_scope'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['language'])
_CAMPAIGNCRITERION.fields_by_name['language'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['ip_block'])
_CAMPAIGNCRITERION.fields_by_name['ip_block'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['content_label'])
_CAMPAIGNCRITERION.fields_by_name['content_label'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['carrier'])
_CAMPAIGNCRITERION.fields_by_name['carrier'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['user_interest'])
_CAMPAIGNCRITERION.fields_by_name['user_interest'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['webpage'])
_CAMPAIGNCRITERION.fields_by_name['webpage'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['operating_system_version'])
_CAMPAIGNCRITERION.fields_by_name['operating_system_version'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['mobile_device'])
_CAMPAIGNCRITERION.fields_by_name['mobile_device'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['location_group'])
_CAMPAIGNCRITERION.fields_by_name['location_group'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
_CAMPAIGNCRITERION.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNCRITERION.fields_by_name['custom_affinity'])
_CAMPAIGNCRITERION.fields_by_name['custom_affinity'].containing_oneof = _CAMPAIGNCRITERION.oneofs_by_name['criterion']
DESCRIPTOR.message_types_by_name['CampaignCriterion'] = _CAMPAIGNCRITERION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignCriterion = _reflection.GeneratedProtocolMessageType('CampaignCriterion', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNCRITERION,
  __module__ = 'google.ads.googleads_v2.proto.resources.campaign_criterion_pb2'
  ,
  __doc__ = """A campaign criterion.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign criterion. Campaign
          criterion resource names have the form:  ``customers/{customer
          _id}/campaignCriteria/{campaign_id}~{criterion_id}``
      campaign:
          The campaign to which the criterion belongs.
      criterion_id:
          The ID of the criterion.  This field is ignored during mutate.
      bid_modifier:
          The modifier for the bids when the criterion matches. The
          modifier must be in the range: 0.1 - 10.0. Most targetable
          criteria types support modifiers. Use 0 to opt out of a Device
          type.
      negative:
          Whether to target (``false``) or exclude (``true``) the
          criterion.
      type:
          The type of the criterion.
      status:
          The status of the criterion.
      criterion:
          The campaign criterion.  Exactly one must be set.
      keyword:
          Keyword.
      placement:
          Placement.
      mobile_app_category:
          Mobile app category.
      mobile_application:
          Mobile application.
      location:
          Location.
      device:
          Device.
      ad_schedule:
          Ad Schedule.
      age_range:
          Age range.
      gender:
          Gender.
      income_range:
          Income range.
      parental_status:
          Parental status.
      user_list:
          User List.
      youtube_video:
          YouTube Video.
      youtube_channel:
          YouTube Channel.
      proximity:
          Proximity.
      topic:
          Topic.
      listing_scope:
          Listing scope.
      language:
          Language.
      ip_block:
          IpBlock.
      content_label:
          ContentLabel.
      carrier:
          Carrier.
      user_interest:
          User Interest.
      webpage:
          Webpage.
      operating_system_version:
          Operating system version.
      mobile_device:
          Mobile Device.
      location_group:
          Location Group
      custom_affinity:
          Custom Affinity.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.CampaignCriterion)
  ))
_sym_db.RegisterMessage(CampaignCriterion)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
